package com.ruoyi.business.service;

import java.util.List;
import java.util.Map;

import com.ruoyi.business.domain.HwDeviceMode;
import com.ruoyi.business.domain.HwDeviceModeFunction;
import com.ruoyi.business.domain.HwDeviceModeParameter;

/**
 * 设备模型Service接口
 * 
 * @author xins
 * @date 2023-09-04
 */
public interface IHwDeviceModeService 
{
    /**
     * 查询设备模型
     * 
     * @param deviceModeId 设备模型主键
     * @return 设备模型
     */
    public HwDeviceMode selectHwDeviceModeByDeviceModeId(Long deviceModeId);

    /**
     * 查询设备模型列表
     * 
     * @param hwDeviceMode 设备模型
     * @return 设备模型集合
     */
    public List<HwDeviceMode> selectHwDeviceModeList(HwDeviceMode hwDeviceMode);

    /**
     * 新增设备模型
     * 
     * @param hwDeviceMode 设备模型
     * @return 结果
     */
    public int insertHwDeviceMode(HwDeviceMode hwDeviceMode);

    /**
     * 修改设备模型
     * 
     * @param hwDeviceMode 设备模型
     * @return 结果
     */
    public int updateHwDeviceMode(HwDeviceMode hwDeviceMode);

    /**
     * 批量删除设备模型
     * 
     * @param deviceModeIds 需要删除的设备模型主键集合
     * @return 结果
     */
    public int deleteHwDeviceModeByDeviceModeIds(Long[] deviceModeIds);

    /**
     * 删除设备模型信息
     * 
     * @param deviceModeId 设备模型主键
     * @return 结果
     */
    public int deleteHwDeviceModeByDeviceModeId(Long deviceModeId);


    /**
     * 新增设备模型功能
     *
     * @param hwDeviceModeFunction 设备模型功能
     * @return 结果
     */
    public Long insertHwDeviceModeFunction(HwDeviceModeFunction hwDeviceModeFunction);

    /**
     * 修改设备模型功能
     *
     * @param hwDeviceModeFunction 设备模型功能
     * @return 结果
     */
    public int updateHwDeviceModeFunction(HwDeviceModeFunction hwDeviceModeFunction);


    /**
     * 删除设备模型功能信息
     *
     * @param modeFunctionId 设备模型功能主键
     * @return 结果
     */
    public int deleteHwDeviceModeFunctionByModeFunctionId(Long modeFunctionId);


    /**
     * @param: modeFunctionId
     * @description 根据设备功能主键获取参数信息列表
     * @author xins
     * @date 2023-09-12 10:45
     * @return Map<String, List<HwDeviceModeParameter>>
     */
    public Map<String, List<HwDeviceModeParameter>> selectDeviceModeParametersByModeFunctionId(Long modeFunctionId);

}
